@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ import (
 	"fmt"
 	"strconv"
 
-	"git.zabbix.com/ap/plugin-support/zbxerr"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // queriesHandler executes select from pg_database command and returns JSON if all is OK or nil otherwise.
